==> fontman-0.1.0.tar.gz: fontman-0.1.0/README.md <==
<p align="center">
  <a href="https://github.com/nschloe/fontman"><img alt="fontman" src="https://nschloe.github.io/fontman/logo-path.svg" width="60%"></a>
  <p align="center">Your font manager.</p>
</p>

[![PyPi Version](https://img.shields.io/pypi/v/fontman.svg?style=flat-square)](https://pypi.org/project/fontman)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/fontman.svg?style=flat-square)](https://pypi.org/pypi/fontman/)
[![GitHub stars](https://img.shields.io/github/stars/nschloe/fontman.svg?style=flat-square&logo=github&label=Stars&logoColor=white)](https://github.com/nschloe/fontman)
[![PyPi downloads](https://img.shields.io/pypi/dm/fontman.svg?style=flat-square)](https://pypistats.org/packages/fontman)

[![gh-actions](https://img.shields.io/github/workflow/status/nschloe/fontman/ci?style=flat-square)](https://github.com/nschloe/fontman/actions?query=workflow%3Aci)
[![codecov](https://img.shields.io/codecov/c/github/nschloe/fontman.svg?style=flat-square)](https://codecov.io/gh/nschloe/fontman)
[![LGTM](https://img.shields.io/lgtm/grade/python/github/nschloe/fontman.svg?style=flat-square)](https://lgtm.com/projects/g/nschloe/fontman)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg?style=flat-square)](https://github.com/psf/black)

Fonts used to be an install-and-forget thing, but many of are now updated regularly.
_fontman_ helps you keep track of the fonts you installed and updates them from GitHub.

Install with
```
pip install fontman
```
and use as
```
fontman install microsoft/cascadia-code rsms/inter
```
Other commands are `remove` and `update`
```
fontman up
```
which updates all your installed fonts.

<img src="https://nschloe.github.io/fontman/terminal.gif" width="70%"/>


### License
This software is published under the [MIT license](https://en.wikipedia.org/wiki/MIT_License).

==> fontman-0.1.1.tar.gz: fontman-0.1.1/README.md <==
<p align="center">
  <a href="https://github.com/nschloe/fontman"><img alt="fontman" src="https://nschloe.github.io/fontman/logo-path.svg" width="60%"></a>
  <p align="center">Your font manager.</p>
</p>

[![PyPi Version](https://img.shields.io/pypi/v/fontman.svg?style=flat-square)](https://pypi.org/project/fontman)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/fontman.svg?style=flat-square)](https://pypi.org/pypi/fontman/)
[![GitHub stars](https://img.shields.io/github/stars/nschloe/fontman.svg?style=flat-square&logo=github&label=Stars&logoColor=white)](https://github.com/nschloe/fontman)
[![PyPi downloads](https://img.shields.io/pypi/dm/fontman.svg?style=flat-square)](https://pypistats.org/packages/fontman)

[![gh-actions](https://img.shields.io/github/workflow/status/nschloe/fontman/ci?style=flat-square)](https://github.com/nschloe/fontman/actions?query=workflow%3Aci)
[![codecov](https://img.shields.io/codecov/c/github/nschloe/fontman.svg?style=flat-square)](https://codecov.io/gh/nschloe/fontman)
[![LGTM](https://img.shields.io/lgtm/grade/python/github/nschloe/fontman.svg?style=flat-square)](https://lgtm.com/projects/g/nschloe/fontman)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg?style=flat-square)](https://github.com/psf/black)

Fonts used to be an install-and-forget thing, but many of are now updated regularly.
_fontman_ helps you keep track of the fonts you installed and updates them from GitHub.

Install with
```sh
pip install fontman
```
and use as
```sh
fontman install microsoft/cascadia-code rsms/inter ibm/plex==v5.1.3
```
Other commands are `remove` and `update`
```sh
fontman up
```
which updates all your installed fonts.

<img src="https://nschloe.github.io/fontman/terminal.gif" width="70%"/>
